@@ -6,7 +6,7 @@ Math::Disarrange::List - Generate all disarrangements of a list.
 
  use Math::Disarrange::List;
 
- Disarrange {say "@_"} qw(a b c);
+ disarrange {say "@_"} qw(a b c);
 
  #  c a b
  #  b c a
@@ -60,7 +60,7 @@ use vars qw(@ISA @EXPORT $VERSION);
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw(disarrange);
-$VERSION = '1.002';
+$VERSION = '1.004'; # Saturday 21 March 2009
 
 =head1 Description
 
@@ -71,7 +71,8 @@ original list in which no element is in its original position.
 C<disarrange()> returns the number of disarrangements in both scalar and
 array context.
 
-Its easy to use and fast. Its written in 100% Pure Perl.
+C<disarrange()> is easy to use and fast. It is written in 100% Pure
+Perl.
 
 Please note that the order in which the disarrangements are generated is
 not guaranteed, so please do not rely on it.
@@ -105,7 +106,15 @@ http://www.handybackup.com
 
 =head1 See Also
 
-L<Math::Permute::List>
+=over
+
+=item L<Math::Cartesian::List>
+
+=item L<Math::Permute::List>
+
+=item L<Math::Subsets::List>
+
+=back
 
 =head1 Copyright
 
